"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Applies a bitwise XOR to the contents of two buffers. Returns a new buffer.
 *
 * @example
 * bitwise.buffer.xor(buffer1, buffer2, false) => Buffer(buffer1 XOR buffer2)
 *
 * @param {Buffer} buffer1 first buffer
 * @param {Buffer} buffer2 second buffer
 * @param {Boolean} isLooping loop through first buffer
 * @return {Buffer} buffer1 XOR buffer2
 */
exports.default = (function (buffer1, buffer2, isLooping) {
    if (isLooping === void 0) { isLooping = false; }
    var length = isLooping ? buffer2.length : buffer1.length;
    var result = Buffer.alloc(length);
    for (var i = 0; i < length; i++) {
        var j = isLooping ? i % buffer1.length : i;
        result[i] = buffer1[j] ^ buffer2[i];
    }
    return result;
});
